/****************************************************************************************
   Temperatur Logger - Software for logging temperature data with the DS18B20 and ESP32
   Written by Sebastian Hinz, https://www.diy-temperature-logger.com
   Licensed under GPLv3. See LICENSE for details.
****************************************************************************************/
#ifndef _WEBDEBUG_H_
#define _WEBDEBUG_H_

#define DEBUG_LINE_LENGTH 30
#define DEBUG_TIMESTAMP   10  // 9 characters + LF
#define DEBUG_LINE_CNT    30

//////////////////////////////////////////////////////////////////////
// deklaration tskTaskControlBlock
typedef struct tskTaskControlBlock
{
  volatile StackType_t    *pxTopOfStack;  /*< Points to the location of the last item placed on the tasks stack.  THIS MUST BE THE FIRST MEMBER OF THE TCB STRUCT. */
  
#if ( portUSING_MPU_WRAPPERS == 1 )
      xMPU_SETTINGS   xMPUSettings;       /*< The MPU settings are defined as part of the port layer.  THIS MUST BE THE SECOND MEMBER OF THE TCB STRUCT. */
  #endif

  ListItem_t          xStateListItem; /*< The list that the state list item of a task is reference from denotes the state of that task (Ready, Blocked, Suspended ). */
  ListItem_t          xEventListItem;     /*< Used to reference a task from an event list. */
  UBaseType_t         uxPriority;         /*< The priority of the task.  0 is the lowest priority. */
  StackType_t         *pxStack;           /*< Points to the start of the stack. */
  char                pcTaskName[ configMAX_TASK_NAME_LEN ];/*< Descriptive name given to the task when created.  Facilitates debugging only. */ /*lint !e971 Unqualified char types are allowed for strings and single characters only. */
};

//////////////////////////////////////////////////////////////////////
class WebDebug
{
public:
  WebDebug();
  static WebDebug& GetInstance();
  
  char* getFreeBuffer();
  void printSerial();
  size_t CreateSortedRingbuffer();
  static size_t printDebugData(uint8_t *buffer, size_t maxLen, size_t alreadySent);
  void system_info();

private:  
  int m_actIndex;
  char m_RingBuffer[DEBUG_LINE_CNT*(DEBUG_LINE_LENGTH+DEBUG_TIMESTAMP)];
  static char *m_SortedRingBuffer[DEBUG_LINE_CNT];
};

#endif
